@@ -15,5 +15,5 @@ pub mod prelude;
 pub use auto::*;
 
 //mod resource;
-//mod sparql_connection;
+mod sparql_connection;
 mod sparql_cursor;
